@@ -7,14 +7,17 @@
 #include "bluetoothdevicelink.h"
 
 #include "../linkprovider.h"
+#include "bluetoothdownloadjob.h"
 #include "bluetoothlinkprovider.h"
 #include "bluetoothuploadjob.h"
-#include "bluetoothdownloadjob.h"
-#include "core_debug.h"
 #include "connectionmultiplexer.h"
+#include "core_debug.h"
 #include "multiplexchannel.h"
 
-BluetoothDeviceLink::BluetoothDeviceLink(const QString& deviceId, LinkProvider* parent, ConnectionMultiplexer* connection, QSharedPointer<MultiplexChannel> socket)
+BluetoothDeviceLink::BluetoothDeviceLink(const QString &deviceId,
+                                         LinkProvider *parent,
+                                         ConnectionMultiplexer *connection,
+                                         QSharedPointer<MultiplexChannel> socket)
     : DeviceLink(deviceId, parent)
     , mSocketReader(new DeviceLineReader(socket.data(), this))
     , mConnection(connection)
@@ -23,10 +26,10 @@ BluetoothDeviceLink::BluetoothDeviceLink(const QString& deviceId, LinkProvider*
 {
     connect(mSocketReader, &DeviceLineReader::readyRead, this, &BluetoothDeviceLink::dataReceived);
 
-    //We take ownership of the connection.
-    //When the link provider destroys us,
-    //the socket (and the reader) will be
-    //destroyed as well
+    // We take ownership of the connection.
+    // When the link provider destroys us,
+    // the socket (and the reader) will be
+    // destroyed as well
     mConnection->setParent(this);
     connect(socket.data(), &MultiplexChannel::aboutToClose, this, &QObject::deleteLater);
 }
@@ -36,49 +39,53 @@ QString BluetoothDeviceLink::name()
     return QStringLiteral("BluetoothLink"); // Should be same in both android and kde version
 }
 
-bool BluetoothDeviceLink::sendPacket(NetworkPacket& np)
+bool BluetoothDeviceLink::sendPacket(NetworkPacket &np)
 {
     if (np.hasPayload()) {
-        BluetoothUploadJob* uploadJob = new BluetoothUploadJob(np.payload(), mConnection, this);
+        BluetoothUploadJob *uploadJob = new BluetoothUploadJob(np.payload(), mConnection, this);
         np.setPayloadTransferInfo(uploadJob->transferInfo());
         uploadJob->start();
     }
-    //TODO: handle too-big packets
+    // TODO: handle too-big packets
     int written = mSocketReader->write(np.serialize());
     return (written != -1);
 }
 
-void BluetoothDeviceLink::userRequestsPair() {
+void BluetoothDeviceLink::userRequestsPair()
+{
     mPairingHandler->requestPairing();
 }
 
-void BluetoothDeviceLink::userRequestsUnpair() {
+void BluetoothDeviceLink::userRequestsUnpair()
+{
     mPairingHandler->unpair();
 }
 
-bool BluetoothDeviceLink::linkShouldBeKeptAlive() {
+bool BluetoothDeviceLink::linkShouldBeKeptAlive()
+{
     return pairStatus() == Paired;
 }
 
 void BluetoothDeviceLink::dataReceived()
 {
-    if (mSocketReader->bytesAvailable() == 0) return;
+    if (mSocketReader->bytesAvailable() == 0)
+        return;
 
     const QByteArray serializedPacket = mSocketReader->readLine();
 
-    //qCDebug(KDECONNECT_CORE) << "BluetoothDeviceLink dataReceived" << packet;
+    // qCDebug(KDECONNECT_CORE) << "BluetoothDeviceLink dataReceived" << packet;
 
     NetworkPacket packet((QString()));
     NetworkPacket::unserialize(serializedPacket, &packet);
 
     if (packet.type() == PACKET_TYPE_PAIR) {
-        //TODO: Handle pair/unpair requests and forward them (to the pairing handler?)
+        // TODO: Handle pair/unpair requests and forward them (to the pairing handler?)
         mPairingHandler->packetReceived(packet);
         return;
     }
 
     if (packet.hasPayloadTransferInfo()) {
-        BluetoothDownloadJob* downloadJob = new BluetoothDownloadJob(mConnection, packet.payloadTransferInfo(), this);
+        BluetoothDownloadJob *downloadJob = new BluetoothDownloadJob(mConnection, packet.payloadTransferInfo(), this);
         downloadJob->start();
         packet.setPayload(downloadJob->payload(), packet.payloadSize());
     }
@@ -89,3 +96,8 @@ void BluetoothDeviceLink::dataReceived()
         QMetaObject::invokeMethod(this, &BluetoothDeviceLink::dataReceived, Qt::QueuedConnection);
     }
 }
+
+QSslCertificate BluetoothDeviceLink::certificate() const
+{
+    return QSslCertificate({}); // TODO Not sure what to do here. For LanDeviceLink we use the SSL connection's certificate, but we don't have that here
+}
