@@ -9,50 +9,48 @@
 
 #include <KLocalizedString>
 
-#include <QString>
 #include <QDBusPendingReply>
-#include <QIcon>
 #include <QDBusServiceWatcher>
+#include <QIcon>
+#include <QString>
 
 #include "dbusinterfaces.h"
 #include <dbushelper.h>
 
 #include "interfaces_debug.h"
 
-static QString createId() { return QCoreApplication::instance()->applicationName()+QString::number(QCoreApplication::applicationPid()); }
+static QString createId()
+{
+    return QCoreApplication::instance()->applicationName() + QString::number(QCoreApplication::applicationPid());
+}
 
 Q_GLOBAL_STATIC_WITH_ARGS(QString, s_keyId, (createId()));
 
-DevicesModel::DevicesModel(QObject* parent)
+DevicesModel::DevicesModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_dbusInterface(new DaemonDbusInterface(this))
     , m_displayFilter(StatusFilterFlag::NoFilter)
 {
+    connect(this, &QAbstractItemModel::rowsRemoved, this, &DevicesModel::rowsChanged);
+    connect(this, &QAbstractItemModel::rowsInserted, this, &DevicesModel::rowsChanged);
 
-    connect(this, &QAbstractItemModel::rowsRemoved,
-            this, &DevicesModel::rowsChanged);
-    connect(this, &QAbstractItemModel::rowsInserted,
-            this, &DevicesModel::rowsChanged);
+    connect(m_dbusInterface, SIGNAL(deviceAdded(QString)), this, SLOT(deviceAdded(QString)));
+    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged, this, &DevicesModel::deviceUpdated);
+    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceRemoved, this, &DevicesModel::deviceRemoved);
 
-    connect(m_dbusInterface, SIGNAL(deviceAdded(QString)),
-            this, SLOT(deviceAdded(QString)));
-    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceVisibilityChanged,
-            this, &DevicesModel::deviceUpdated);
-    connect(m_dbusInterface, &OrgKdeKdeconnectDaemonInterface::deviceRemoved,
-            this, &DevicesModel::deviceRemoved);
-
-    QDBusServiceWatcher* watcher = new QDBusServiceWatcher(DaemonDbusInterface::activatedService(),
-                                                           DBusHelper::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+    QDBusServiceWatcher *watcher =
+        new QDBusServiceWatcher(DaemonDbusInterface::activatedService(), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &DevicesModel::refreshDeviceList);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, &DevicesModel::clearDevices);
 
-    //refresh the view, acquireDiscoveryMode if necessary
+    // refresh the view, acquireDiscoveryMode if necessary
     setDisplayFilter(NoFilter);
 }
 
-QHash< int, QByteArray > DevicesModel::roleNames() const
+QHash<int, QByteArray> DevicesModel::roleNames() const
 {
     QHash<int, QByteArray> names = QAbstractItemModel::roleNames();
+    names.insert(NameModelRole, "name");
     names.insert(IdModelRole, "deviceId");
     names.insert(IconNameRole, "iconName");
     names.insert(DeviceRole, "device");
@@ -65,9 +63,9 @@ DevicesModel::~DevicesModel()
     m_dbusInterface->releaseDiscoveryMode(*s_keyId);
 }
 
-int DevicesModel::rowForDevice(const QString& id) const
+int DevicesModel::rowForDevice(const QString &id) const
 {
-    for (int i = 0, c=m_deviceList.size(); i<c; ++i) {
+    for (int i = 0, c = m_deviceList.size(); i < c; ++i) {
         if (m_deviceList[i]->id() == id) {
             return i;
         }
@@ -75,17 +73,17 @@ int DevicesModel::rowForDevice(const QString& id) const
     return -1;
 }
 
-void DevicesModel::deviceAdded(const QString& id)
+void DevicesModel::deviceAdded(const QString &id)
 {
     if (rowForDevice(id) >= 0) {
         Q_ASSERT_X(false, "deviceAdded", "Trying to add a device twice");
         return;
     }
 
-    DeviceDbusInterface* dev = new DeviceDbusInterface(id, this);
+    DeviceDbusInterface *dev = new DeviceDbusInterface(id, this);
     Q_ASSERT(dev->isValid());
 
-    if (! passesFilter(dev)) {
+    if (!passesFilter(dev)) {
         delete dev;
         return;
     }
@@ -95,17 +93,17 @@ void DevicesModel::deviceAdded(const QString& id)
     endInsertRows();
 }
 
-void DevicesModel::deviceRemoved(const QString& id)
+void DevicesModel::deviceRemoved(const QString &id)
 {
     int row = rowForDevice(id);
-    if (row>=0) {
+    if (row >= 0) {
         beginRemoveRows(QModelIndex(), row, row);
         delete m_deviceList.takeAt(row);
         endRemoveRows();
     }
 }
 
-void DevicesModel::deviceUpdated(const QString& id, bool isVisible)
+void DevicesModel::deviceUpdated(const QString &id, bool isVisible)
 {
     Q_UNUSED(isVisible);
     int row = rowForDevice(id);
@@ -120,8 +118,8 @@ void DevicesModel::deviceUpdated(const QString& id, bool isVisible)
         qCDebug(KDECONNECT_INTERFACES) << "Adding missing or previously removed device" << id;
         deviceAdded(id);
     } else {
-        DeviceDbusInterface* dev = getDevice(row);
-        if (! passesFilter(dev)) {
+        DeviceDbusInterface *dev = getDevice(row);
+        if (!passesFilter(dev)) {
             beginRemoveRows(QModelIndex(), row, row);
             delete m_deviceList.takeAt(row);
             endRemoveRows();
@@ -163,13 +161,12 @@ void DevicesModel::refreshDeviceList()
     bool onlyReachable = (m_displayFilter & StatusFilterFlag::Reachable);
 
     QDBusPendingReply<QStringList> pendingDeviceIds = m_dbusInterface->devices(onlyReachable, onlyPaired);
-    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(pendingDeviceIds, this);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingDeviceIds, this);
 
-    QObject::connect(watcher, &QDBusPendingCallWatcher::finished,
-                     this, &DevicesModel::receivedDeviceList);
+    QObject::connect(watcher, &QDBusPendingCallWatcher::finished, this, &DevicesModel::receivedDeviceList);
 }
 
-void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher* watcher)
+void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher *watcher)
 {
     watcher->deleteLater();
     clearDevices();
@@ -185,23 +182,23 @@ void DevicesModel::receivedDeviceList(QDBusPendingCallWatcher* watcher)
     if (deviceIds.isEmpty())
         return;
 
-    beginInsertRows(QModelIndex(), 0, deviceIds.count()-1);
-    for (const QString& id : deviceIds) {
+    beginInsertRows(QModelIndex(), 0, deviceIds.count() - 1);
+    for (const QString &id : deviceIds) {
         appendDevice(new DeviceDbusInterface(id, this));
     }
     endInsertRows();
 }
 
-void DevicesModel::appendDevice(DeviceDbusInterface* dev)
+void DevicesModel::appendDevice(DeviceDbusInterface *dev)
 {
     m_deviceList.append(dev);
     connect(dev, &OrgKdeKdeconnectDeviceInterface::nameChanged, this, &DevicesModel::nameChanged);
 }
 
-void DevicesModel::nameChanged(const QString& newName)
+void DevicesModel::nameChanged(const QString &newName)
 {
     Q_UNUSED(newName);
-    DeviceDbusInterface* device = static_cast<DeviceDbusInterface*>(sender());
+    DeviceDbusInterface *device = static_cast<DeviceDbusInterface *>(sender());
 
     Q_ASSERT(rowForDevice(device->id()) >= 0);
 
@@ -218,58 +215,55 @@ void DevicesModel::clearDevices()
     }
 }
 
-QVariant DevicesModel::data(const QModelIndex& index, int role) const
+QVariant DevicesModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid()
-        || index.row() < 0
-        || index.row() >= m_deviceList.size())
-    {
+    if (!index.isValid() || index.row() < 0 || index.row() >= m_deviceList.size()) {
         return QVariant();
     }
 
     Q_ASSERT(m_dbusInterface->isValid());
 
-    DeviceDbusInterface* device = m_deviceList[index.row()];
+    DeviceDbusInterface *device = m_deviceList[index.row()];
     Q_ASSERT(device->isValid());
 
-    //This function gets called lots of times, producing lots of dbus calls. Add a cache?
+    // This function gets called lots of times, producing lots of dbus calls. Add a cache?
     switch (role) {
-        case Qt::SizeHintRole:
-            return QSize(0, 32);
-        case IconModelRole: {
-            QString icon = data(index, IconNameRole).toString();
-            return QIcon::fromTheme(icon);
+    case Qt::SizeHintRole:
+        return QSize(0, 32);
+    case IconModelRole: {
+        QString icon = data(index, IconNameRole).toString();
+        return QIcon::fromTheme(icon);
+    }
+    case IdModelRole:
+        return device->id();
+    case NameModelRole:
+        return device->name();
+    case Qt::ToolTipRole: {
+        bool trusted = device->isTrusted();
+        bool reachable = device->isReachable();
+        QString status = reachable ? (trusted ? i18n("Device trusted and connected") : i18n("Device not trusted")) : i18n("Device disconnected");
+        return status;
+    }
+    case StatusModelRole: {
+        int status = StatusFilterFlag::NoFilter;
+        if (device->isReachable()) {
+            status |= StatusFilterFlag::Reachable;
         }
-        case IdModelRole:
-            return device->id();
-        case NameModelRole:
-            return device->name();
-        case Qt::ToolTipRole: {
-            bool trusted = device->isTrusted();
-            bool reachable = device->isReachable();
-            QString status = reachable? (trusted? i18n("Device trusted and connected") : i18n("Device not trusted")) : i18n("Device disconnected");
-            return status;
+        if (device->isTrusted()) {
+            status |= StatusFilterFlag::Paired;
         }
-        case StatusModelRole: {
-            int status = StatusFilterFlag::NoFilter;
-            if (device->isReachable()) {
-                status |= StatusFilterFlag::Reachable;
-            }
-            if (device->isTrusted()) {
-                status |= StatusFilterFlag::Paired;
-            }
-            return status;
-        }
-        case IconNameRole:
-            return device->statusIconName();
-        case DeviceRole:
-            return QVariant::fromValue<QObject*>(device);
-        default:
-            return QVariant();
+        return status;
+    }
+    case IconNameRole:
+        return device->statusIconName();
+    case DeviceRole:
+        return QVariant::fromValue<QObject *>(device);
+    default:
+        return QVariant();
     }
 }
 
-DeviceDbusInterface* DevicesModel::getDevice(int row) const
+DeviceDbusInterface *DevicesModel::getDevice(int row) const
 {
     if (row < 0 || row >= m_deviceList.size()) {
         return nullptr;
@@ -278,17 +272,17 @@ DeviceDbusInterface* DevicesModel::getDevice(int row) const
     return m_deviceList[row];
 }
 
-int DevicesModel::rowCount(const QModelIndex& parent) const
+int DevicesModel::rowCount(const QModelIndex &parent) const
 {
-    if(parent.isValid()) {
-        //Return size 0 if we are a child because this is not a tree
+    if (parent.isValid()) {
+        // Return size 0 if we are a child because this is not a tree
         return 0;
     }
 
     return m_deviceList.size();
 }
 
-bool DevicesModel::passesFilter(DeviceDbusInterface* dev) const
+bool DevicesModel::passesFilter(DeviceDbusInterface *dev) const
 {
     bool onlyPaired = (m_displayFilter & StatusFilterFlag::Paired);
     bool onlyReachable = (m_displayFilter & StatusFilterFlag::Reachable);
